==> openshift-model-monitoring-5.12.0-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/Sigv4Builder.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class Sigv4Builder extends io.fabric8.openshift.api.model.monitoring.v1.Sigv4FluentImpl<io.fabric8.openshift.api.model.monitoring.v1.Sigv4Builder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.monitoring.v1.Sigv4,io.fabric8.openshift.api.model.monitoring.v1.Sigv4Builder>{
  public Sigv4Builder() {
    this(false);
  }
  public Sigv4Builder(java.lang.Boolean validationEnabled) {
    this(new Sigv4(), validationEnabled);
  }
  public Sigv4Builder(io.fabric8.openshift.api.model.monitoring.v1.Sigv4Fluent<?> fluent) {
    this(fluent, false);
  }
  public Sigv4Builder(io.fabric8.openshift.api.model.monitoring.v1.Sigv4Fluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new Sigv4(), validationEnabled);
  }
  public Sigv4Builder(io.fabric8.openshift.api.model.monitoring.v1.Sigv4Fluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1.Sigv4 instance) {
    this(fluent, instance, false);
  }
  public Sigv4Builder(io.fabric8.openshift.api.model.monitoring.v1.Sigv4Fluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1.Sigv4 instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAccessKey(instance.getAccessKey()); 
    fluent.withProfile(instance.getProfile()); 
    fluent.withRegion(instance.getRegion()); 
    fluent.withRoleArn(instance.getRoleArn()); 
    fluent.withSecretKey(instance.getSecretKey()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public Sigv4Builder(io.fabric8.openshift.api.model.monitoring.v1.Sigv4 instance) {
    this(instance,false);
  }
  public Sigv4Builder(io.fabric8.openshift.api.model.monitoring.v1.Sigv4 instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAccessKey(instance.getAccessKey()); 
    this.withProfile(instance.getProfile()); 
    this.withRegion(instance.getRegion()); 
    this.withRoleArn(instance.getRoleArn()); 
    this.withSecretKey(instance.getSecretKey()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.monitoring.v1.Sigv4Fluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.monitoring.v1.Sigv4 build() {
    Sigv4 buildable = new Sigv4(fluent.getAccessKey(),fluent.getProfile(),fluent.getRegion(),fluent.getRoleArn(),fluent.getSecretKey());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    Sigv4Builder that = (Sigv4Builder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-monitoring-6.5.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/Sigv4Builder.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class Sigv4Builder extends Sigv4FluentImpl<Sigv4Builder> implements VisitableBuilder<Sigv4,Sigv4Builder>{
  public Sigv4Builder() {
    this(false);
  }
  public Sigv4Builder(Boolean validationEnabled) {
    this(new Sigv4(), validationEnabled);
  }
  public Sigv4Builder(Sigv4Fluent<?> fluent) {
    this(fluent, false);
  }
  public Sigv4Builder(Sigv4Fluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new Sigv4(), validationEnabled);
  }
  public Sigv4Builder(Sigv4Fluent<?> fluent,Sigv4 instance) {
    this(fluent, instance, false);
  }
  public Sigv4Builder(Sigv4Fluent<?> fluent,Sigv4 instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAccessKey(instance.getAccessKey()); 
    fluent.withProfile(instance.getProfile()); 
    fluent.withRegion(instance.getRegion()); 
    fluent.withRoleArn(instance.getRoleArn()); 
    fluent.withSecretKey(instance.getSecretKey()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public Sigv4Builder(Sigv4 instance) {
    this(instance,false);
  }
  public Sigv4Builder(Sigv4 instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withAccessKey(instance.getAccessKey()); 
    this.withProfile(instance.getProfile()); 
    this.withRegion(instance.getRegion()); 
    this.withRoleArn(instance.getRoleArn()); 
    this.withSecretKey(instance.getSecretKey()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  Sigv4Fluent<?> fluent;
  Boolean validationEnabled;
  public Sigv4 build() {
    Sigv4 buildable = new Sigv4(fluent.getAccessKey(),fluent.getProfile(),fluent.getRegion(),fluent.getRoleArn(),fluent.getSecretKey());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
